@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -41,14 +41,14 @@ APIS_METADATA = [
         ],
     },
     {
-        "name": "test_connection",
-        "description": "Test a connection",
+        "name": "run_automation",
+        "description": "Run an automation workflow",
         "http_method": "POST",
         "arguments": [],
         "post_arguments": [
             {
-                "name": "service_connection",
-                "description": "TestServiceConnectionRequest config to test",
+                "name": "automation_workflow",
+                "description": "AutomationWorkflow request",
                 "required": True,
             },
         ],
