@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,7 +15,7 @@ import traceback
 from typing import Callable, Optional
 
 import requests
-from flask import Blueprint
+from flask import Blueprint, escape
 from openmetadata_managed_apis.api.response import ApiResponse
 from openmetadata_managed_apis.utils.logger import routes_logger
 from requests.exceptions import ConnectionError
@@ -67,11 +67,10 @@ def get_fn(blueprint: Blueprint) -> Callable:
         """
 
         try:
-
             for ip_service in IP_SERVICES:
                 host_ip = _get_ip_safely(ip_service)
                 if host_ip:
-                    return ApiResponse.success({"ip": host_ip})
+                    return ApiResponse.success({"ip": escape(host_ip)})
 
             # If we cannot fetch the IP, still return a 200 but without informing the IP.
             return ApiResponse.success({"ip": "unknown"})
