@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,7 +16,11 @@ from typing import Callable
 
 from flask import Blueprint, Response, request
 from openmetadata_managed_apis.api.response import ApiResponse
-from openmetadata_managed_apis.api.utils import get_arg_dag_id, get_request_arg
+from openmetadata_managed_apis.api.utils import (
+    get_arg_dag_id,
+    get_request_arg,
+    sanitize_task_id,
+)
 from openmetadata_managed_apis.operations.last_dag_logs import last_dag_logs
 from openmetadata_managed_apis.utils.logger import routes_logger
 
@@ -45,7 +49,15 @@ def get_fn(blueprint: Blueprint) -> Callable:
         """
 
         dag_id = get_arg_dag_id()
-        task_id = get_request_arg(request, "task_id")
+        raw_task_id = get_request_arg(request, "task_id")
+        task_id = sanitize_task_id(raw_task_id)
+
+        if task_id is None:
+            return ApiResponse.error(
+                status=ApiResponse.STATUS_BAD_REQUEST,
+                error="Invalid or missing task_id parameter",
+            )
+
         after = get_request_arg(request, "after", raise_missing=False)
 
         try:
