@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,10 +18,11 @@ from multiprocessing import Process
 from typing import Optional
 
 from airflow import settings
-from airflow.jobs.scheduler_job import SchedulerJob
 from airflow.models import DagBag
+from airflow.version import version as airflow_version
 from flask import request
 from openmetadata_managed_apis.utils.logger import api_logger
+from packaging import version
 
 logger = api_logger()
 
@@ -52,6 +53,16 @@ def clean_dag_id(raw_dag_id: Optional[str]) -> Optional[str]:
     return re.sub("[^0-9a-zA-Z-_]+", "_", raw_dag_id) if raw_dag_id else None
 
 
+def sanitize_task_id(raw_task_id: Optional[str]) -> Optional[str]:
+    """
+    Sanitize task_id to prevent path traversal attacks.
+    Only allows alphanumeric characters, dashes, and underscores.
+    :param raw_task_id: Raw task ID from user input
+    :return: Sanitized task ID safe for file path construction
+    """
+    return re.sub("[^0-9a-zA-Z-_]+", "_", raw_task_id) if raw_task_id else None
+
+
 def get_request_arg(req, arg, raise_missing: bool = True) -> Optional[str]:
     """
     Pick up the `arg` from the flask `req`.
@@ -98,6 +109,16 @@ def get_request_dag_id() -> Optional[str]:
     return clean_dag_id(raw_dag_id)
 
 
+def get_request_conf() -> Optional[dict]:
+    """
+    Try to fetch the conf from the JSON request. Return None if no conf is provided.
+    """
+    try:
+        return request.get_json().get("conf")
+    except Exception:
+        return None
+
+
 def get_dagbag():
     """
     Load the dagbag from Airflow settings
@@ -110,15 +131,49 @@ def get_dagbag():
 
 class ScanDagsTask(Process):
     def run(self):
-        scheduler_job = SchedulerJob(num_times_parse_dags=1)
-        scheduler_job.heartrate = 0
-        scheduler_job.run()
+        if version.parse(airflow_version) >= version.parse("2.6"):
+            scheduler_job = self._run_new_scheduler_job()
+        else:
+            scheduler_job = self._run_old_scheduler_job()
         try:
             scheduler_job.kill()
         except Exception as exc:
             logger.debug(traceback.format_exc())
             logger.info(f"Rescan Complete: Killed Job: {exc}")
 
+    @staticmethod
+    def _run_new_scheduler_job() -> "Job":
+        """
+        Run the new scheduler job from Airflow 2.6
+        """
+        from airflow.jobs.job import Job, run_job
+        from airflow.jobs.scheduler_job_runner import SchedulerJobRunner
+
+        scheduler_job = Job()
+        job_runner = SchedulerJobRunner(
+            job=scheduler_job,
+            num_runs=1,
+        )
+        scheduler_job.heartrate = 0
+
+        # pylint: disable=protected-access
+        run_job(scheduler_job, execute_callable=job_runner._execute)
+
+        return scheduler_job
+
+    @staticmethod
+    def _run_old_scheduler_job() -> "SchedulerJob":
+        """
+        Run the old scheduler job before 2.6
+        """
+        from airflow.jobs.scheduler_job import SchedulerJob
+
+        scheduler_job = SchedulerJob(num_times_parse_dags=1)
+        scheduler_job.heartrate = 0
+        scheduler_job.run()
+
+        return scheduler_job
+
 
 def scan_dags_job_background():
     """
