@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,37 +15,42 @@ import json
 import uuid
 from datetime import datetime, timedelta
 from functools import partial
-from typing import Callable
+from typing import Callable, Optional, Union
 
-import airflow
 from airflow import DAG
 from openmetadata_managed_apis.api.utils import clean_dag_id
 from pydantic import ValidationError
 from requests.utils import quote
 
+from metadata.generated.schema.entity.services.apiService import ApiService
 from metadata.generated.schema.entity.services.dashboardService import DashboardService
 from metadata.generated.schema.entity.services.databaseService import DatabaseService
 from metadata.generated.schema.entity.services.messagingService import MessagingService
 from metadata.generated.schema.entity.services.metadataService import MetadataService
 from metadata.generated.schema.entity.services.mlmodelService import MlModelService
 from metadata.generated.schema.entity.services.pipelineService import PipelineService
-from metadata.generated.schema.tests.testSuite import TestSuite
-from metadata.ingestion.models.encoders import show_secrets_encoder
+from metadata.generated.schema.entity.services.searchService import SearchService
+from metadata.generated.schema.entity.services.storageService import StorageService
+from metadata.generated.schema.metadataIngestion.application import (
+    OpenMetadataApplicationConfig,
+)
+from metadata.generated.schema.type.basic import Timestamp, Uuid
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
+from metadata.utils import fqn
+from metadata.workflow.base import BaseWorkflow
 
+# pylint: disable=ungrouped-imports
 try:
     from airflow.operators.python import PythonOperator
 except ModuleNotFoundError:
     from airflow.operators.python_operator import PythonOperator
 
+from croniter import croniter
 from openmetadata_managed_apis.utils.logger import set_operator_logger, workflow_logger
 from openmetadata_managed_apis.utils.parser import (
     parse_service_connection,
     parse_validation_err,
 )
-from openmetadata_managed_apis.workflows.ingestion.credentials_builder import (
-    build_secrets_manager_credentials,
-)
 
 from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
     IngestionPipeline,
@@ -63,12 +68,22 @@ from metadata.ingestion.api.parser import (
     InvalidWorkflowException,
     ParsingConfigurationError,
 )
-from metadata.ingestion.api.workflow import Workflow
 from metadata.ingestion.ometa.utils import model_str
+from metadata.workflow.metadata import MetadataWorkflow
 
 logger = workflow_logger()
 
-# logging.getLogger("airflow.task.operators").setLevel(logging.WARNING)
+ENTITY_CLASS_MAP = {
+    "apiService": ApiService,
+    "databaseService": DatabaseService,
+    "pipelineService": PipelineService,
+    "dashboardService": DashboardService,
+    "messagingService": MessagingService,
+    "mlmodelService": MlModelService,
+    "metadataService": MetadataService,
+    "storageService": StorageService,
+    "searchService": SearchService,
+}
 
 
 class InvalidServiceException(Exception):
@@ -84,9 +99,11 @@ class GetServiceException(Exception):
 
     def __init__(self, service_type: str, service_name: str):
         self.message = (
-            f"Could not get service from type {service_type}. This means that the"
+            f"Could not get service from type [{service_type}]. This means that the"
             " OpenMetadata client running in the Airflow host had issues getting"
-            f" the service {service_name}. Validate your ingestion-bot authentication."
+            f" the service [{service_name}]. Make sure the ingestion-bot JWT token"
+            " is valid and that the Workflow is deployed with the latest one. If this error"
+            " persists, recreate the JWT token and redeploy the Workflow."
         )
         super().__init__(self.message)
 
@@ -105,15 +122,12 @@ def build_source(ingestion_pipeline: IngestionPipeline) -> WorkflowSource:
     :param ingestion_pipeline: With the service ref
     :return: WorkflowSource
     """
-    secrets_manager = (
-        ingestion_pipeline.openMetadataServerConnection.secretsManagerProvider
-    )
-    ingestion_pipeline.openMetadataServerConnection.secretsManagerCredentials = (
-        build_secrets_manager_credentials(secrets_manager)
-    )
 
     try:
         metadata = OpenMetadata(config=ingestion_pipeline.openMetadataServerConnection)
+
+        # check we can access OM server
+        metadata.health_check()
     except Exception as exc:
         raise ClientInitializationError(
             f"Failed to initialize the OpenMetadata client due to: {exc}."
@@ -124,53 +138,26 @@ def build_source(ingestion_pipeline: IngestionPipeline) -> WorkflowSource:
 
     service_type = ingestion_pipeline.service.type
 
-    if service_type == "testSuite":
-        service = metadata.get_by_name(
-            entity=TestSuite, fqn=ingestion_pipeline.service.name
-        )  # check we are able to access OM server
-        if not service:
-            raise GetServiceException(service_type, ingestion_pipeline.service.name)
+    entity_class = ENTITY_CLASS_MAP.get(service_type)
+    try:
+        if service_type == "testSuite":
+            return WorkflowSource(
+                type=service_type,
+                serviceName=ingestion_pipeline.service.name,
+                sourceConfig=ingestion_pipeline.sourceConfig,
+                # retrieved from the test suite workflow using the `sourceConfig.config.entityFullyQualifiedName`
+                serviceConnection=None,
+            )
 
-        return WorkflowSource(
-            type=service_type,
-            serviceName=ingestion_pipeline.service.name,
-            sourceConfig=ingestion_pipeline.sourceConfig,
+        if entity_class is None:
+            raise InvalidServiceException(f"Invalid Service Type: {service_type}")
+
+        service = metadata.get_by_name(
+            entity=entity_class,
+            fqn=ingestion_pipeline.service.name,
+            nullable=False,
         )
 
-    entity_class = None
-    try:
-        if service_type == "databaseService":
-            entity_class = DatabaseService
-            service: DatabaseService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        elif service_type == "pipelineService":
-            entity_class = PipelineService
-            service: PipelineService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        elif service_type == "dashboardService":
-            entity_class = DashboardService
-            service: DashboardService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        elif service_type == "messagingService":
-            entity_class = MessagingService
-            service: MessagingService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        elif service_type == "mlmodelService":
-            entity_class = MlModelService
-            service: MlModelService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        elif service_type == "metadataService":
-            entity_class = MetadataService
-            service: MetadataService = metadata.get_by_name(
-                entity=entity_class, fqn=ingestion_pipeline.service.name
-            )
-        else:
-            raise InvalidServiceException(f"Invalid Service Type: {service_type}")
     except ValidationError as original_error:
         try:
             resp = metadata.client.get(
@@ -200,12 +187,24 @@ def build_source(ingestion_pipeline: IngestionPipeline) -> WorkflowSource:
 
     return WorkflowSource(
         type=service.serviceType.value.lower(),
-        serviceName=service.name.__root__,
+        serviceName=service.name.root,
         serviceConnection=service.connection,
         sourceConfig=ingestion_pipeline.sourceConfig,
     )
 
 
+def execute_workflow(
+    workflow: BaseWorkflow, workflow_config: OpenMetadataWorkflowConfig
+) -> None:
+    """
+    Execute the workflow and handle the status
+    """
+    workflow.execute()
+    workflow.stop()
+    if workflow_config.workflowConfig.raiseOnError:
+        workflow.raise_from_status()
+
+
 def metadata_ingestion_workflow(workflow_config: OpenMetadataWorkflowConfig):
     """
     Task that creates and runs the ingestion workflow.
@@ -218,13 +217,11 @@ def metadata_ingestion_workflow(workflow_config: OpenMetadataWorkflowConfig):
 
     set_operator_logger(workflow_config)
 
-    config = json.loads(workflow_config.json(encoder=show_secrets_encoder))
-    workflow = Workflow.create(config)
-
-    workflow.execute()
-    workflow.raise_from_status()
-    workflow.print_status()
-    workflow.stop()
+    config = json.loads(
+        workflow_config.model_dump_json(exclude_defaults=False, mask_secrets=False)
+    )
+    workflow = MetadataWorkflow.create(config)
+    execute_workflow(workflow, workflow_config)
 
 
 def build_workflow_config_property(
@@ -237,23 +234,53 @@ def build_workflow_config_property(
     """
     return WorkflowConfig(
         loggerLevel=ingestion_pipeline.loggerLevel or LogLevels.INFO,
+        raiseOnError=ingestion_pipeline.raiseOnError,
         openMetadataServerConfig=ingestion_pipeline.openMetadataServerConnection,
     )
 
 
+def clean_name_tag(tag: str) -> Optional[str]:
+    """
+    Clean the tag to be used in Airflow.
+    Airflow supports 100 characters. We'll keep just 90
+    since we add prefixes on the tags
+    """
+    if not tag:
+        return None
+    try:
+        return fqn.split(tag)[-1][:90]
+    except Exception as exc:
+        logger.warning("Error cleaning tag: %s", exc)
+        return tag[:90]
+
+
 def build_dag_configs(ingestion_pipeline: IngestionPipeline) -> dict:
     """
     Prepare kwargs to send to DAG
     :param ingestion_pipeline: pipeline configs
     :return: dict to use as kwargs
     """
+    # Determine start_date based on schedule_interval using croniter
+    schedule_interval = ingestion_pipeline.airflowConfig.scheduleInterval
+    now = datetime.now()
+
+    if schedule_interval is None:
+        # On-demand DAG, set start_date to now
+        start_date = now
+    elif croniter.is_valid(schedule_interval):
+        cron = croniter(schedule_interval, now)
+        start_date = cron.get_prev(datetime)
+    else:
+        # Handle invalid cron expressions if necessary
+        start_date = now
+
     return {
-        "dag_id": clean_dag_id(ingestion_pipeline.name.__root__),
-        "description": ingestion_pipeline.description,
-        "start_date": ingestion_pipeline.airflowConfig.startDate.__root__
-        if ingestion_pipeline.airflowConfig.startDate
-        else airflow.utils.dates.days_ago(1),
-        "end_date": ingestion_pipeline.airflowConfig.endDate.__root__
+        "dag_id": clean_dag_id(ingestion_pipeline.name.root),
+        "description": ingestion_pipeline.description.root
+        if ingestion_pipeline.description is not None
+        else None,
+        "start_date": start_date,
+        "end_date": ingestion_pipeline.airflowConfig.endDate.root
         if ingestion_pipeline.airflowConfig.endDate
         else None,
         "concurrency": ingestion_pipeline.airflowConfig.concurrency,
@@ -266,15 +293,18 @@ def build_dag_configs(ingestion_pipeline: IngestionPipeline) -> dict:
         "is_paused_upon_creation": ingestion_pipeline.airflowConfig.pausePipeline
         or False,
         "catchup": ingestion_pipeline.airflowConfig.pipelineCatchup or False,
-        "schedule_interval": ingestion_pipeline.airflowConfig.scheduleInterval,
+        "schedule_interval": schedule_interval,
         "tags": [
             "OpenMetadata",
-            ingestion_pipeline.pipelineType.value,
+            clean_name_tag(ingestion_pipeline.displayName)
+            or clean_name_tag(ingestion_pipeline.name.root),
+            f"type:{ingestion_pipeline.pipelineType.value}",
+            f"service:{clean_name_tag(ingestion_pipeline.service.name)}",
         ],
     }
 
 
-def send_failed_status_callback(workflow_config: OpenMetadataWorkflowConfig, _):
+def send_failed_status_callback(workflow_config: OpenMetadataWorkflowConfig, *_, **__):
     """
     Airflow on_failure_callback to update workflow status if something unexpected
     happens or if the DAG is externally killed.
@@ -305,9 +335,10 @@ def send_failed_status_callback(workflow_config: OpenMetadataWorkflowConfig, _):
         )
 
         pipeline_status = metadata.get_pipeline_status(
-            workflow_config.ingestionPipelineFQN, str(workflow_config.pipelineRunId)
+            workflow_config.ingestionPipelineFQN,
+            str(workflow_config.pipelineRunId.root),
         )
-        pipeline_status.endDate = datetime.now().timestamp() * 1000
+        pipeline_status.endDate = Timestamp(int(datetime.now().timestamp() * 1000))
         pipeline_status.pipelineState = PipelineState.failed
 
         metadata.create_or_update_pipeline_status(
@@ -319,34 +350,56 @@ def send_failed_status_callback(workflow_config: OpenMetadataWorkflowConfig, _):
         )
 
 
+class CustomPythonOperator(PythonOperator):
+    def on_kill(self) -> None:
+        """
+        Override this method to clean up subprocesses when a task instance
+        gets killed. Any use of the threading, subprocess or multiprocessing
+        module within an operator needs to be cleaned up, or it will leave
+        ghost processes behind.
+        """
+        workflow_config = self.op_kwargs.get("workflow_config")
+        if workflow_config:
+            send_failed_status_callback(workflow_config)
+
+
 def build_dag(
     task_name: str,
     ingestion_pipeline: IngestionPipeline,
-    workflow_config: OpenMetadataWorkflowConfig,
+    workflow_config: Union[OpenMetadataWorkflowConfig, OpenMetadataApplicationConfig],
     workflow_fn: Callable,
+    params: Optional[dict] = None,
 ) -> DAG:
     """
     Build a simple metadata workflow DAG
+    :param task_name: Name of the task
+    :param ingestion_pipeline: Pipeline configs
+    :param workflow_config: Workflow configurations
+    :param workflow_fn: Function to be executed
+    :param params: Optional parameters to pass to the operator
+    :return: DAG
     """
 
     with DAG(**build_dag_configs(ingestion_pipeline)) as dag:
-
         # Initialize with random UUID4. Will be used by the callback instead of
         # generating it inside the Workflow itself.
-        workflow_config.pipelineRunId = str(uuid.uuid4())
+        workflow_config.pipelineRunId = Uuid(uuid.uuid4())
 
-        PythonOperator(
+        CustomPythonOperator(
             task_id=task_name,
             python_callable=workflow_fn,
-            op_kwargs={"workflow_config": workflow_config},
+            op_kwargs={
+                "workflow_config": workflow_config,
+            },
             # There's no need to retry if we have had an error. Wait until the next schedule or manual rerun.
-            retries=0,
+            retries=ingestion_pipeline.airflowConfig.retries or 0,
             # each DAG will call its own OpenMetadataWorkflowConfig
             on_failure_callback=partial(send_failed_status_callback, workflow_config),
             # Add tag and ownership to easily identify DAGs generated by OM
-            owner=ingestion_pipeline.owner.name
-            if ingestion_pipeline.owner
+            owner=ingestion_pipeline.owners.root[0].name
+            if (ingestion_pipeline.owners and ingestion_pipeline.owners.root)
             else "openmetadata",
+            params=params,
         )
 
         return dag
