@@ -1,8 +1,8 @@
-#  Copyright 2021 Collate
-#  Licensed under the Apache License, Version 2.0 (the "License");
+#  Copyright 2025 Collate
+#  Licensed under the Collate Community License, Version 1.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-#  http://www.apache.org/licenses/LICENSE-2.0
+#  https://github.com/open-metadata/OpenMetadata/blob/main/ingestion/LICENSE
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -11,15 +11,16 @@
 """
 Metadata DAG function builder
 """
+import json
 import tempfile
-from pathlib import Path
 
 from airflow import DAG
+from openmetadata_managed_apis.utils.logger import set_operator_logger
 from openmetadata_managed_apis.workflows.ingestion.common import (
     build_dag,
     build_source,
     build_workflow_config_property,
-    metadata_ingestion_workflow,
+    execute_workflow,
 )
 
 from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
@@ -31,6 +32,28 @@ from metadata.generated.schema.metadataIngestion.workflow import (
     Processor,
     Stage,
 )
+from metadata.workflow.usage import UsageWorkflow
+
+
+def usage_workflow(
+    workflow_config: OpenMetadataWorkflowConfig,
+):
+    """
+    Task that creates and runs the ingestion workflow.
+
+    The workflow_config gets cooked form the incoming
+    ingestionPipeline.
+
+    This is the callable used to create the PythonOperator
+    """
+
+    set_operator_logger(workflow_config)
+
+    config = json.loads(
+        workflow_config.model_dump_json(exclude_defaults=False, mask_secrets=False)
+    )
+    workflow = UsageWorkflow.create(config)
+    execute_workflow(workflow, workflow_config)
 
 
 def build_usage_config_from_file(
@@ -59,7 +82,8 @@ def build_usage_config_from_file(
             config={"filename": filename},
         ),
         workflowConfig=build_workflow_config_property(ingestion_pipeline),
-        ingestionPipelineFQN=ingestion_pipeline.fullyQualifiedName.__root__,
+        ingestionPipelineFQN=ingestion_pipeline.fullyQualifiedName.root,
+        enableStreamableLogs=ingestion_pipeline.enableStreamableLogs,
     )
 
 
@@ -76,10 +100,6 @@ def build_usage_workflow_config(
             workflow_config = build_usage_config_from_file(ingestion_pipeline, tmp_file)
 
     else:
-        # If dir does not exist, create it
-        if not Path(location).parent.is_dir():
-            Path(location).parent.mkdir(parents=True, exist_ok=True)
-
         workflow_config = build_usage_config_from_file(ingestion_pipeline, location)
 
     return workflow_config
@@ -94,7 +114,7 @@ def build_usage_dag(airflow_pipeline: IngestionPipeline) -> DAG:
         task_name="usage_task",
         ingestion_pipeline=airflow_pipeline,
         workflow_config=workflow_config,
-        workflow_fn=metadata_ingestion_workflow,
+        workflow_fn=usage_workflow,
     )
 
     return dag
